@@ -1,5 +1,5 @@
 # WordNet::Similarity::lesk.pm version 2.04
-# (Last updated $Id: lesk.pm,v 1.29 2008/03/27 06:21:17 sidz1979 Exp $)
+# (Last updated $Id: lesk.pm,v 1.30 2015/10/04 15:06:16 tpederse Exp $)
 #
 # Module to accept two WordNet synsets and to return a floating point
 # number that indicates how similar those two synsets are, using an
@@ -258,7 +258,10 @@ sub getRelatedness
         
 	my $overlapsTraceString = "";
 	my $key;
-	foreach $key (keys %{$overlaps})
+	# modified by tdp oct 4 2015 to make matching more robust
+	# results from keys can come back in various orders, so sort them
+	#	foreach $key (keys %{$overlaps})
+	foreach $key (sort keys %{$overlaps})
 	{
 	    # find the length of the key, square it, multiply with its
 	    # value and finally with the weight associated with this
