@@ -1,41 +1,35 @@
-#! /usr/local/bin/perl -w
+#! /usr/bin/perl -w
 #
-# rawtextFreq.pl version 2.04
-# (Last updated $Id: rawtextFreq.pl,v 1.23 2008/04/13 09:27:52 sidz1979 Exp $)
+# rawtextFreq.pl version 2.05
+# (Last updated $Id: rawtextFreq.pl,v 1.27 2008/06/03 00:04:43 sidz1979 Exp $)
 #
 # -----------------------------------------------------------------------------
-
 use strict;
 use File::Find;
+use WordNet::Similarity::FrequencyCounter;
 
 # Variable declarations
 my %stopWords;
 my %offsetFreq;
-my %newFreq;
-my %topHash;
 
 # Some modules used
 use Getopt::Long;
 use WordNet::QueryData;
 use WordNet::Tools;
 
-
 # First check if no commandline options have been provided... in which case
 # print out the usage notes!
-if ($#ARGV == -1)
+if($#ARGV == -1)
 {
-    &minimalUsageNotes();
-    exit 1;
+  &minimalUsageNotes();
+  exit 1;
 }
-
 our @opt_infiles;
 our ($opt_version, $opt_help, $opt_stopfile, $opt_outfile);
 our ($opt_wnpath, $opt_resnik, $opt_smooth, $opt_stdin);
 
 # Now get the options!
-my $ok = GetOptions("version", "help", "stopfile=s", "outfile=s",
-		    "wnpath=s", "resnik", "smooth=s", "stdin",
-		    "infile=s" => \@opt_infiles);
+my $ok = GetOptions("version", "help", "stopfile=s", "outfile=s","wnpath=s", "resnik", "smooth=s", "stdin","infile=s" => \@opt_infiles);
 
 # GetOptions should have already printed out a detail error message if
 # $ok is false
@@ -44,85 +38,81 @@ $ok or die "Error getting command-line arguments\n";
 # If the version information has been requested
 if(defined $opt_version)
 {
-    $opt_version = 1;
-    &printVersion();
-    exit 0;
+  &printVersion();
+  exit 0;
 }
 
 # If detailed help has been requested
 if(defined $opt_help)
 {
-    $opt_help = 1;
-    &printHelp();
-    exit 0;
+  &printHelp();
+  exit 0;
 }
 
 # make sure either --stdin or --infile was given
-unless ($opt_stdin or scalar @opt_infiles) {
-    minimalUsageNotes ();
-    exit 1;
+unless($opt_stdin or scalar @opt_infiles)
+{
+  minimalUsageNotes();
+  exit 1;
 }
 
 # make sure that both --stdin and --infile were NOT given
-if ($opt_stdin and scalar @opt_infiles) {
-    minimalUsageNotes ();
-    exit 1;
+if($opt_stdin and scalar @opt_infiles)
+{
+  minimalUsageNotes();
+  exit 1;
 }
 
-my $outfile;
-if(defined $opt_outfile)
+# make sure --outfile is given
+if(!defined $opt_outfile)
 {
-    $outfile = $opt_outfile;
-}
-else
-{
-    &minimalUsageNotes();
-    exit 1;
+  &minimalUsageNotes();
+  exit 1;
 }
 
 # Load the stop words if specified
 if(defined $opt_stopfile)
 {
-    print STDERR "Loading stoplist... ";
-    open (WORDS, '<', "$opt_stopfile") or die "Couldn't open $opt_stopfile.\n";
-    while (<WORDS>)
-    {
-	s/[\r\f\n]//g;
-	$stopWords{$_} = 1;
-    }
-    close WORDS;
-    print STDERR "done.\n";
+  print STDERR "Loading stoplist... ";
+  open(WORDS, '<', "$opt_stopfile") or die "Couldn't open $opt_stopfile.\n";
+  while(<WORDS>)
+  {
+    s/[\r\f\n]//g;
+    $stopWords{$_} = 1;
+  }
+  close WORDS;
+  print STDERR "done.\n";
 }
 
-my ($wnPCPath, $wnUnixPath);
-
 # Get the path to WordNet...
+my ($wnPCPath, $wnUnixPath);
 if(defined $opt_wnpath)
 {
-    $wnPCPath = $opt_wnpath;
-    $wnUnixPath = $opt_wnpath;
+  $wnPCPath = $opt_wnpath;
+  $wnUnixPath = $opt_wnpath;
 }
-elsif (defined $ENV{WNSEARCHDIR})
+elsif(defined $ENV{WNSEARCHDIR})
 {
-    $wnPCPath = $ENV{WNSEARCHDIR};
-    $wnUnixPath = $ENV{WNSEARCHDIR};
+  $wnPCPath = $ENV{WNSEARCHDIR};
+  $wnUnixPath = $ENV{WNSEARCHDIR};
 }
-elsif (defined $ENV{WNHOME})
+elsif(defined $ENV{WNHOME})
 {
-    $wnPCPath = $ENV{WNHOME} . "\\dict";
-    $wnUnixPath = $ENV{WNHOME} . "/dict";
+  $wnPCPath = $ENV{WNHOME} . "\\dict";
+  $wnUnixPath = $ENV{WNHOME} . "/dict";
 }
 else
 {
-    $wnPCPath = "C:\\Program Files\\WordNet\\3.0\\dict";
-    $wnUnixPath = "/usr/local/WordNet-3.0/dict";
+  $wnPCPath = "C:\\Program Files\\WordNet\\3.0\\dict";
+  $wnUnixPath = "/usr/local/WordNet-3.0/dict";
 }
 
 # Load up WordNet
 print STDERR "Loading WordNet... ";
-my $wn = (defined $opt_wnpath)
-         ? (WordNet::QueryData->new($opt_wnpath))
-         : (WordNet::QueryData->new());
+my $wn =
+    (defined $opt_wnpath)
+  ? (WordNet::QueryData->new($opt_wnpath))
+  : (WordNet::QueryData->new());
 die "Unable to create WordNet::QueryData object.\n" if(!$wn);
 $wnPCPath = $wnUnixPath = $wn->dataPath() if(defined $wn->can('dataPath'));
 my $wntools = WordNet::Tools->new($wn);
@@ -131,7 +121,8 @@ print STDERR "done.\n";
 
 # Load the topmost nodes of the hierarchies
 print STDERR "Loading topmost nodes of the hierarchies... ";
-&createTopHash();
+my $topHash = WordNet::Similarity::FrequencyCounter::createTopHash($wn);
+die "Unable to create topHash.\n" if(!defined($topHash));
 print STDERR "done.\n";
 
 # Read the input, form sentences and process each
@@ -143,135 +134,122 @@ print STDERR "done.\n";
 #  on a line, and the second word of the compound could be the first word
 #  on the next line).
 my $sentence = "";
+
 # check if we're reading from a file or from STDIN
-if (scalar @opt_infiles) {
-
-    # first we have to figure out what files to process.  The files
-    # are specified with in --infile option.  The value of the option
-    # can be a filename, a directory, or a pattern (as understood by
-    # Perl's glob() function).
-    my @infiles = getFiles (@opt_infiles);
-
-    print STDERR "Computing frequencies.\n";
-    foreach my $i (0..$#infiles) {
-	my $infile = $infiles[$i];
-
-	print STDERR ("  Processing '$infile' (", $i + 1, "/",
-		      $#infiles + 1, " files)... ");
-	
-	open (IFH, '<', $infile) or die "Cannot open file '$infile': $!";
-	while (my $line = <IFH>)
-	{
-	    $line =~ s/[\r\f\n]//g;
-	    my @parts = split (/[.?!,;:]/, $line);
-	    foreach (1..$#parts)
-	    {
-		$sentence .= shift(@parts)." ";
-		process ($sentence);
-		$sentence = "";
-	    }
-	    $sentence .= shift(@parts)." " if(@parts);
-	}
-	process ($sentence);
-	close IFH or die "Cannot not close file '$infile': $!";
-	print STDERR "  done.\n";
-    }
-}
-else {
-    print STDERR "Computing frequencies... ";
-    while (my $line = <STDIN>)
+if(scalar @opt_infiles)
+{
+  # first we have to figure out what files to process.  The files
+  # are specified with in --infile option.  The value of the option
+  # can be a filename, a directory, or a pattern (as understood by
+  # Perl's glob() function).
+  my @infiles = getFiles(@opt_infiles);
+  print STDERR "Computing frequencies...\n";
+  foreach my $i (0..$#infiles)
+  {
+    my $infile = $infiles[$i];
+    print STDERR ("  Processing '$infile' (", $i + 1, "/",$#infiles + 1, " files)... ");
+    open(IFH, '<', $infile) or die "Cannot open file '$infile': $!";
+    while(my $line = <IFH>)
     {
-	$line =~ s/[\r\f\n]//g;
-	my @parts = split (/[.?!,;:]/, $line);
-	foreach (1..$#parts)
-	{
-	    $sentence .= shift (@parts) . " ";
-	    process ($sentence);
-	    $sentence = "";
-	}
-	$sentence .= shift (@parts) . " " if @parts;
+      $line =~ s/[\r\f\n]//g;
+      my @parts = split(/[.?!,;:]/, $line);
+      foreach (1..$#parts)
+      {
+        $sentence .= shift(@parts)." ";
+        &process($sentence);
+        $sentence = "";
+      }
+      $sentence .= shift(@parts)." " if(@parts);
     }
-    process ($sentence);
+    &process($sentence);
+    close IFH or die "Cannot not close file '$infile': $!";
+    print STDERR "  done.\n";
+  }
+}
+else
+{
+  print STDERR "Computing frequencies... ";
+  while (my $line = <STDIN>)
+  {
+    $line =~ s/[\r\f\n]//g;
+    my @parts = split(/[.?!,;:]/, $line);
+    foreach (1..$#parts)
+    {
+      $sentence .= shift(@parts) . " ";
+      &process($sentence);
+      $sentence = "";
+    }
+    $sentence .= shift(@parts) . " " if @parts;
+  }
+  &process($sentence);
+  print STDERR "done.\n";
 }
-print STDERR "done.\n";
-
-# Hack to prevent warning...
-$opt_resnik = 1 if defined $opt_resnik;
 
 # Smoothing!
 if(defined $opt_smooth)
 {
-    print STDERR "Smoothing... ";
-    if($opt_smooth eq 'ADD1')
+  print STDERR "Smoothing... ";
+  if($opt_smooth eq 'ADD1')
+  {
+    foreach my $pos ("noun", "verb")
     {
-	foreach my $pos ("noun", "verb")
-	{
-	    my $localpos = $pos;
-
-	    if(!open(IDX, $wnUnixPath."/data.$pos"))
-	    {
-		if(!open(IDX, $wnPCPath."/$pos.dat"))
-		{
-		    print STDERR "Unable to open WordNet data files.\n";
-		    exit;
-		}
-	    }
-	    $localpos =~ s/(^[nv]).*/$1/;
-	    while(<IDX>)
-	    {
-		last if(/^\S/);
-	    }
-	    my ($offset) = split(/\s+/, $_, 2);
-	    $offset =~ s/^0*//;
-	    $offsetFreq{$localpos}{$offset}++;
-	    while(<IDX>)
-	    {
-		($offset) = split(/\s+/, $_, 2);
-		$offset =~ s/^0*//;
-		$offsetFreq{$localpos}{$offset}++;
-	    }
-	    close(IDX);
-	}
-	print STDERR "done.\n";
-    }
-    else
-    {
-	print STDERR "\nWarning: Unknown smoothing '$opt_smooth'.\n";
-	print STDERR "Use --help for details.\n";
-	print STDERR "Continuing without smoothing.\n";
+      my $localpos = $pos;
+      if(!open(IDX, $wnUnixPath."/data.$pos"))
+      {
+        if(!open(IDX, $wnPCPath."/$pos.dat"))
+        {
+          print STDERR "Unable to open WordNet data files.\n";
+          exit;
+        }
+      }
+      $localpos =~ s/(^[nv]).*/$1/;
+      while(<IDX>)
+      {
+        last if(/^\S/);
+      }
+      my ($offset) = split(/\s+/, $_, 2);
+      $offset =~ s/^0*//;
+      $offsetFreq{$localpos}{$offset}++;
+      while(<IDX>)
+      {
+        ($offset) = split(/\s+/, $_, 2);
+        $offset =~ s/^0*//;
+        $offsetFreq{$localpos}{$offset}++;
+      }
+      close(IDX);
     }
+    print STDERR "done.\n";
+  }
+  else
+  {
+    print STDERR "\nWarning: Unknown smoothing '$opt_smooth'.\n";
+    print STDERR "Use --help for details.\n";
+    print STDERR "Continuing without smoothing.\n";
+  }
 }
 
 # Propagating frequencies up the WordNet hierarchies...
 print STDERR "Propagating frequencies up through WordNet... ";
-
-$offsetFreq{"n"}{0} = 0;
-$offsetFreq{"v"}{0} = 0;
-&propagateFrequency(0, "n");
-&propagateFrequency(0, "v");
-delete $newFreq{"n"}{0};
-delete $newFreq{"v"}{0};
+my $newFreq = WordNet::Similarity::FrequencyCounter::propagateFrequency(\%offsetFreq, $wn, $topHash);
 print STDERR "done.\n";
 
 # Print the output to file
 print STDERR "Writing output file... ";
-open(OUT, ">$outfile") || die "Unable to open $outfile for writing: $!\n";
+open(OUT, ">$opt_outfile") || die "Unable to open $opt_outfile for writing: $!\n";
 print OUT "wnver::".$wntools->hashCode()."\n";
 foreach my $pos ("n", "v")
 {
-    foreach my $offset (sort {$a <=> $b} keys %{$newFreq{$pos}})
-    {
-	print OUT "$offset$pos $newFreq{$pos}{$offset}";
-	print OUT " ROOT" if($topHash{$pos}{$offset});
-	print OUT "\n";
-    }
+  foreach my $offset (sort {$a <=> $b} keys %{$newFreq->{$pos}})
+  {
+    print OUT "$offset$pos ".($newFreq->{$pos}->{$offset});
+    print OUT " ROOT" if($topHash->{$pos}->{$offset});
+    print OUT "\n";
+  }
 }
 close(OUT);
 print STDERR "done.\n";
 
-
 # ----------------- Subroutines start Here ----------------------
-
 # Processing of each sentence
 # (1) Convert to lowercase
 # (2) Remove all unwanted characters
@@ -281,256 +259,104 @@ print STDERR "done.\n";
 # (6) Get the frequency counts
 sub process
 {
-    my $block;
+  my $block;
+  $block = lc(shift);
+  $block =~ s/\'//g;
+  $block =~ s/[^a-z0-9]+/ /g;
+  while($block =~ s/([0-9]+)\s+([0-9]+)/$1$2/g){}
+  $block =~ s/^\s+//;
+  $block =~ s/\s+$//;
+  $block = $wntools->compoundify($block);
 
-    $block = lc(shift);
-    $block =~ s/\'//g;
-    $block =~ s/[^a-z0-9]+/ /g;
-    while($block =~ s/([0-9]+)\s+([0-9]+)/$1$2/g){}
-    $block =~ s/^\s+//;
-    $block =~ s/\s+$//;
-    $block = $wntools->compoundify($block);
-
-    while($block =~ /([\w_]+)/g)
-    {
-	&updateFrequency($1) if(!defined $stopWords{$1});
-    }
-}
-
-# Subroutine to update frequency tokens on "seeing" a
-# word in text
-sub updateFrequency
-{
-    my $word;
-    my $pos;
-    my $form;
-    my @senses;
-    my @forms;
-
-    $word = shift;
-    foreach $pos ("n", "v")
-    {
-	@forms = $wn->validForms($word."\#".$pos);
-	foreach $form (@forms)
-	{
-	    push @senses, $wn->querySense($form);
-	}
-	foreach (@senses)
-	{
-	    if(defined $opt_resnik)
-	    {
-		$offsetFreq{$pos}{$wn->offset($_)} += (1/($#senses + 1));
-	    }
-	    else
-	    {
-		$offsetFreq{$pos}{$wn->offset($_)}++;
-	    }
-	}
-    }
-}
-
-# Recursive subroutine that propagates the frequencies up
-# the WordNet hierarchy
-sub propagateFrequency
-{
-    my $node;
-    my $pos;
-    my $sum;
-    my $retValue;
-    my $hyponym;
-    my @hyponyms;
-
-    $node = shift;
-    $pos = shift;
-    if($newFreq{$pos}{$node})
-    {
-	return $newFreq{$pos}{$node};
-    }
-    $retValue = &getHyponymOffsets($node, $pos);
-    if($retValue)
-    {
-	@hyponyms = @{$retValue};
-    }
-    else
-    {
-	$newFreq{$pos}{$node} = $offsetFreq{$pos}{$node}
-	                        ? $offsetFreq{$pos}{$node}
-                                : 0;
-
-	return $offsetFreq{$pos}{$node}
-	       ? $offsetFreq{$pos}{$node}
-               : 0;
-    }
-    $sum = 0;
-    if($#{$retValue} >= 0)
-    {
-	foreach $hyponym (@hyponyms)
-	{
-	    $sum += &propagateFrequency($hyponym, $pos);
-	}
-    }
-    $newFreq{$pos}{$node} = ($offsetFreq{$pos}{$node}
-			     ? $offsetFreq{$pos}{$node}
-			     : 0) + $sum;
-
-    return ($offsetFreq{$pos}{$node}
-	    ? $offsetFreq{$pos}{$node}
-	    : 0) + $sum;
-}
-
-# Subroutine that returns the hyponyms of a given synset.
-sub getHyponymOffsets
-{
-    my $offset;
-    my $wordForm;
-    my $hyponym;
-    my @hyponyms;
-    my @retVal;
-
-    $offset = shift;
-    my $pos = shift;
-    if($offset == 0)
-    {
-	@retVal = keys %{$topHash{$pos}};
-	return [@retVal];
-    }
-    $wordForm = $wn->getSense($offset, $pos);
-    @hyponyms = $wn->querySense($wordForm, "hypos");
-    if(!@hyponyms || $#hyponyms < 0)
-    {
-	return undef;
-    }
-    @retVal = ();
-    foreach $hyponym (@hyponyms)
-    {
-	$offset = $wn->offset($hyponym);
-	push @retVal, $offset;
-    }
-    return [@retVal];
-}
-
-# Creates and loads the topmost nodes hash.
-sub createTopHash
-{
-    my $datapath = $wn->dataPath;
-    my $unixfile_n = "${datapath}/data.noun";
-    my $windozefile_n = "${datapath}\\noun.dat";
-
-    my $nounfile = -e $windozefile_n ? $windozefile_n : $unixfile_n;
-
-    open (NFH, '<', $nounfile) or die "Cannot open '$nounfile': $!";
-
-    while (<NFH>) {
-        next if "  " eq substr $_, 0, 2;
-	next if / \@ \d\d\d\d\d\d\d\d /;
-	next unless /^(\d\d\d\d\d\d\d\d) /;
-	my $offset = $1 + 0;
-
-	# QueryData::getSense will die() if the $offset and pos are not
-	# found.  Putting this in an eval will catch the exception.  See
-	# perldoc -f eval
-	my $wps;
-	eval {$wps = $wn->getSense ($offset, 'n')};
-	if ($@) {
-	    die "(offset '$offset' not found) $@";
-	}
-	$topHash{n}{$offset} = 1;
-    }
-
-    close NFH;
-
-    my $unixfile_v = "${datapath}/data.verb";
-    my $windozefile_v = "${datapath}\\verb.dat";
-
-    my $verbfile = -e $windozefile_v ? $windozefile_v : $unixfile_v;
-
-    open (VFH, '<', $verbfile) or die "Cannot open '$verbfile': $!";
-
-    while (<VFH>) {
-        next if " " eq substr ($_, 0, 2);
-	next if / \@ \d\d\d\d\d\d\d\d /;
-	next unless /^(\d\d\d\d\d\d\d\d) /;
-	my $offset = $1 + 0;
-	$topHash{v}{$offset} = 1;
-    }
-
-    close VFH;
+  while($block =~ /([\w_]+)/g)
+  {
+    WordNet::Similarity::FrequencyCounter::updateWordFrequency($1, \%offsetFreq, $wn, $opt_resnik) if(!defined $stopWords{$1});
+  }
 }
 
 sub getFiles
 {
-    my @inpatterns = @_;
-    my @infiles;
-    # the options to pass to File::Find::find()
-    my %options = (wanted =>
-		   sub {
-		       unless (-d $File::Find::name) {
-			   push @infiles, $File::Find::name;
-		       }
-		   },
-		   follow_fast => 1);
+  my @inpatterns = @_;
+  my @infiles;
 
-    foreach my $pattern (@inpatterns) {
-	if (-d $pattern) {
-	    find (\%options, $pattern);
-	}
-	elsif (-e $pattern and not -d $pattern) {
-	    push @infiles, $pattern;
-	}
-	else {
-	    my @files = glob $pattern;
-	    foreach my $file (@files) {
-		if (-d $file) {
-		    find (\%options, $pattern);
-		}
-		else {
-		    push @infiles, $file;
-		}
-	    }
-	}
+  # the options to pass to File::Find::find()
+  my %options = (
+    wanted => sub {
+      unless(-d $File::Find::name)
+      {
+        push @infiles, $File::Find::name;
+      }
+    },
+    follow_fast => 1
+  );
+  foreach my $pattern (@inpatterns)
+  {
+    if(-d $pattern)
+    {
+      find(\%options, $pattern);
     }
-    return @infiles;
+    elsif(-e $pattern and not -d $pattern)
+    {
+      push @infiles, $pattern;
+    }
+    else
+    {
+      my @files = glob $pattern;
+      foreach my $file (@files)
+      {
+        if(-d $file)
+        {
+          find(\%options, $pattern);
+        }
+        else
+        {
+          push @infiles, $file;
+        }
+      }
+    }
+  }
+  return @infiles;
 }
 
 # Subroutine to print detailed help
 sub printHelp
 {
-    &printUsage();
-    print "\nThis program computes the information content of concepts, by\n";
-    print "counting the frequency of their occurrence in raw text.\n";
-    print "Options: \n";
-    print "--outfile        Specifies the output file OUTFILE.\n";
-    print "--stdin          Read the input from the standard input\n";
-    print "--infile         INFILE is the name of an input file\n";
-    print "--stopfile       STOPFILE is a list of stop listed words that will\n";
-    print "                 not be considered in the frequency count.\n";
-    print "--wnpath         Option to specify WNPATH as the location of WordNet data\n";
-    print "                 files. If this option is not specified, the program tries\n";
-    print "                 to determine the path to the WordNet data files using the\n";
-    print "                 WNHOME environment variable.\n";
-    print "--resnik         Option to specify that the frequency counting should\n";
-    print "                 be performed according to the method described by\n";
-    print "                 Resnik (1995).\n";
-    print "--smooth         Specifies the smoothing to be used on the probabilities\n";
-    print "                 computed. SCHEME specifies the type of smoothing to\n";
-    print "                 perform. It is a string, which can be only be 'ADD1'\n";
-    print "                 as of now. Other smoothing schemes will be added in\n";
-    print "                 future releases.\n";
-    print "--help           Displays this help screen.\n";
-    print "--version        Displays version information.\n\n";
+  &printUsage();
+  print "\nThis program computes the information content of concepts, by\n";
+  print "counting the frequency of their occurrence in raw text.\n";
+  print "Options: \n";
+  print "--outfile        Specifies the output file OUTFILE.\n";
+  print "--stdin          Read the input from the standard input\n";
+  print "--infile         INFILE is the name of an input file\n";
+  print "--stopfile       STOPFILE is a list of stop listed words that will\n";
+  print "                 not be considered in the frequency count.\n";
+  print "--wnpath         Option to specify WNPATH as the location of WordNet data\n";
+  print "                 files. If this option is not specified, the program tries\n";
+  print "                 to determine the path to the WordNet data files using the\n";
+  print "                 WNHOME environment variable.\n";
+  print "--resnik         Option to specify that the frequency counting should\n";
+  print "                 be performed according to the method described by\n";
+  print "                 Resnik (1995).\n";
+  print "--smooth         Specifies the smoothing to be used on the probabilities\n";
+  print "                 computed. SCHEME specifies the type of smoothing to\n";
+  print "                 perform. It is a string, which can be only be 'ADD1'\n";
+  print "                 as of now. Other smoothing schemes will be added in\n";
+  print "                 future releases.\n";
+  print "--help           Displays this help screen.\n";
+  print "--version        Displays version information.\n\n";
 }
 
 # Subroutine to print minimal usage notes
 sub minimalUsageNotes
 {
-    &printUsage();
-    print "Type rawtextFreq.pl --help for detailed help.\n";
+  &printUsage();
+  print "Type rawtextFreq.pl --help for detailed help.\n";
 }
 
 # Subroutine that prints the usage
 sub printUsage
 {
-    print <<'EOT';
+  print <<'EOT';
 Usage: rawtextFreq.pl --outfile OUTFILE
                        {--stdin | --infile FILE [--infile FILE ...]}
                        [--stopfile FILE] [--resnik] [--wnpath PATH]
@@ -542,10 +368,9 @@ EOT
 # Subroutine to print the version information
 sub printVersion
 {
-    print "rawtextFreq.pl version 2.04\n";
-    print "Copyright (c) 2005-2008, Ted Pedersen, Satanjeev Banerjee, Siddharth Patwardhan and Jason Michelizzi.\n";
+  print "rawtextFreq.pl version 2.05\n";
+  print "Copyright (c) 2005-2008, Ted Pedersen, Satanjeev Banerjee, Siddharth Patwardhan and Jason Michelizzi.\n";
 }
-
 __END__
 
 =head1 NAME
